package com.huimv.management.service.impl;

import cn.hutool.core.date.DateUtil;
import com.huimv.management.entity.HealthIsolationRecordEntity;
import com.huimv.management.entity.dto.DiseaseDto;
import com.huimv.management.entity.vo.PigBaseVo;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;
import java.util.Map;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huimv.common.utils.PageUtils;
import com.huimv.common.utils.Query;

import com.huimv.management.dao.HealthMedicalRecordDao;
import com.huimv.management.entity.HealthMedicalRecordEntity;
import com.huimv.management.service.HealthMedicalRecordService;


@Service("healthMedicalRecordService")
public class HealthMedicalRecordServiceImpl extends ServiceImpl<HealthMedicalRecordDao, HealthMedicalRecordEntity> implements HealthMedicalRecordService {

    @Autowired
    private HealthMedicalRecordDao healthMedicalRecordDao;

    @Override
    public PageUtils queryPage(Map<String, Object> params) {

        //根据牧场查询
        String farmId = (String) params.get("formFarmId");
        QueryWrapper<HealthMedicalRecordEntity> wrapper = new QueryWrapper<HealthMedicalRecordEntity>();
        wrapper.eq(StringUtils.isNotBlank(farmId),"farm_id",farmId);

        //耳标
        String pigId = (String) params.get("eartag");
        wrapper.like(StringUtils.isNotBlank(pigId),"pig_id",pigId);

        //疾病名称
        String diseaseName = (String) params.get("diseaseName");
        wrapper.eq(StringUtils.isNotBlank(diseaseName),"disease_name",diseaseName);

        //病因
        String causeName = (String) params.get("causeName");
        wrapper.eq(StringUtils.isNotBlank(causeName),"cause_name",causeName);

        //症状
        String symptomName = (String) params.get("symptomName");
        wrapper.eq(StringUtils.isNotBlank(symptomName),"symptom_name",symptomName);

        //兽医姓名
        String doctor = (String) params.get("doctor");
        wrapper.eq(StringUtils.isNotBlank(doctor),"doctor",doctor);

        //治疗方案
        String treatmentPlan = (String) params.get("treatmentPlan");
        wrapper.eq(StringUtils.isNotBlank(treatmentPlan),"treatment_plan",treatmentPlan);

        //治疗结果
        String result = (String) params.get("result");
        wrapper.eq(StringUtils.isNotBlank(result),"result",result);

        IPage<HealthMedicalRecordEntity> page = this.page(
                new Query<HealthMedicalRecordEntity>().getPage(params),
                wrapper
        );

        return new PageUtils(page);
    }

    @Override
    public List<DiseaseDto> diseaseCount(String type, String farmId) {
        QueryWrapper<HealthMedicalRecordEntity> wrapper = new QueryWrapper<HealthMedicalRecordEntity>();
        wrapper.eq("farm_id",Integer.parseInt(farmId));
        Date endTime = DateUtil.date();
        Date startTime;
        switch (type){
            //今日
            case "1":
                startTime= DateUtil.beginOfDay(endTime);
                break;
            //本月
            case "2":
                startTime= DateUtil.beginOfMonth(endTime);
                break;
            //本周
            default:
                startTime = DateUtil.beginOfWeek(endTime);
        }

        //小于
        wrapper.le("create_time",endTime);
        //大于等于
        wrapper.ge("create_time",startTime);

        wrapper.apply("effective = 1");

        List<DiseaseDto> diseaseDtos  = healthMedicalRecordDao.diseaseCount(wrapper);
        return diseaseDtos;
    }
}